@@ -11,6 +11,17 @@ try:
 except:
     import launchpadBugs.utils as utils
 
+def status_importance_case_callback(option, opt_str, value, parser):
+    result = list()
+    values = value.split(",")
+    for v in values:
+        if v.lower().endswith("w/") or v.lower().endswith("w/o"):
+            result.append(v.lstrip().capitalize())
+        else:
+            x = v.split()
+            result.append(" ".join([i.capitalize() for i in x]))
+    setattr(parser.values, option.dest, ",".join(result))
+
 class commandLine:
     def __init__(self, prog=None):
         parser = OptionParser(version=utils.find_version_number())
@@ -38,12 +49,12 @@ class commandLine:
             parser.add_option("-f", "--filterbug", type="string", 
                                     dest="filterbug", metavar="BUGNUMBER[,BUGNUMBER,...]",
                                     help="don't show provided bug number(s)")
-            parser.add_option("--status", type="string", dest="status",
-                                    default="", metavar="STATUS",
-                                    help="filter on provided status")
-            parser.add_option("--importance", type="string", dest="importance",
-                                    default="", metavar="IMPORTANCE",
-                                    help="filter on provided importance")
+            parser.add_option("--status", action="callback", callback=status_importance_case_callback,
+                                    dest="status", default="", metavar="STATUS",
+                                    type="string", help="filter on provided status")
+            parser.add_option("--importance", action="callback", callback=status_importance_case_callback,
+                                    dest="importance", default="", metavar="IMPORTANCE",
+                                    type="string", help="filter on provided importance")
             parser.add_option("--tag", type="string", dest="tag",
                                     default="", metavar="TAG[,TAG,...]",
                                     help="filter on bug tag(s)")
@@ -81,7 +92,7 @@ package assigned or no clue file for the package exists")
             parser.add_option("--footer", type="string", dest="footer",
                               default="", metavar="(s|t|st)",
                               help="show (s)tatistical or date/(t)ime information in the footer")
-            parser.add_option("--file", type="string", dest="filename",
+            parser.add_option("--file", type="string", dest="file",
                               default="", help="print to file")
             parser.add_option("--gen-config", action="store_true", 
                               dest="gen_config",
@@ -141,12 +152,12 @@ package assigned or no clue file for the package exists")
             parser.add_option("--count", action="store_true",
                                     dest="count", 
                                     help="count the number of comments") 
-            parser.add_option("--status", type="string", dest="status",
-                                    default="", metavar="STATUS",
-                                    help="filter on provided status")
-            parser.add_option("--importance", type="string", dest="importance",
-                                    default="", metavar="IMPORTANCE",
-                                    help="filter on provided importance")
+            parser.add_option("--status", action="callback", callback=status_importance_case_callback,
+                                    dest="status", default="", metavar="STATUS",
+                                    type="string", help="filter on provided status")
+            parser.add_option("--importance", action="callback", callback=status_importance_case_callback,
+                                    dest="importance", default="", metavar="IMPORTANCE",
+                                    type="string", help="filter on provided importance")
             parser.add_option("--component", type="string", dest="component",
                                     default="", metavar="COMPONENT",
                                     help="filter on provided component")
@@ -156,6 +167,15 @@ package assigned or no clue file for the package exists")
             parser.add_option("--reporter", type="string", dest="reporter",
                                     default="", metavar="LAUNCHPAD-LOGIN",
                                     help="filter on the reporter")
+            parser.add_option("--subscriber", type="string", dest="subscriber",
+                                    default="", metavar="LAUNCHPAD-LOGIN",
+                                    help="filter on a subscriber")
+            parser.add_option("--commenter", type="string", dest="commenter",
+                                    default="", metavar="LAUNCHPAD-LOGIN",
+                                    help="filter on a commenter")
+            parser.add_option("--supervisor", type="string", dest="supervisor",
+                                    default="", metavar="LAUNCHPAD-LOGIN",
+                                    help="filter on the bug supervisor")
             parser.add_option("--nd", type="string", dest="no_duplicates",
                                     default="", metavar='"(<|>)<INT>"',
                                     help="filter on the number of duplicates")
@@ -171,6 +191,12 @@ package assigned or no clue file for the package exists")
             parser.add_option("--lc", type="string", dest="lastcomment",
                                     default="", metavar="COMMENT_SPEC",
                                     help='''filter on the last comment's author (u:LAUNCHPAD-LOGIN) and/or date (d:YYYY-MM-DD) of last comment e.g. --lc "u:brian-murray&d:2007-12-04"''')
+            parser.add_option("--dc", type="string", dest="date_created",
+                                    default="", metavar="DATE_SPEC",
+                                    help='filter on the date a bug task was created')
+            parser.add_option("--du", type="string", dest="date_updated",
+                                    default="", metavar="DATE_SPEC",
+                                    help='filter on the date a bug was updated')
             parser.add_option("--patch", action="store_true", 
                                     dest="patch",
                                     help="filter for bugs containing a patch attached")
@@ -251,6 +277,9 @@ package assigned or no clue file for the package exists")
             parser.add_option("--countcomments", action="store_true",
                                     dest="countcomments", 
                                     help="show the quantity of comments")
+            parser.add_option("--countcommenters", action="store_true",
+                                    dest="countcommenters", 
+                                    help="show the quantity of unique commenters")
             parser.add_option("-c", "--comment", type="int", dest="comment",
                                     metavar="COMMENTNUMBER", help="show properties of a comment")
             parser.add_option("--author", action="store_true",
